@@ -23,21 +23,37 @@ yatai_proto = LazyLoader('yatai_proto', globals(), 'bentoml.yatai.proto')
 @click.option('--name', help='model name')
 @click.option('--path', help='directory path of pretrained model')
 @click.option('--labels', help='comma separated list of key:val pairs')
-def pack(module, clz, name, path, labels=None, opts=None):
+@click.option('--files', help='comma separated list of file paths to add')
+def pack(module, clz, name, path, labels=None, files=None, opts=None):
+    # Create a service instance
+    svc = get_instance(module, clz)
+
+    names = [x.strip() for x in name.split(',')]
+    paths = [x.strip() for x in path.split(',')]
+    if ((len(names) + len(paths)) / 2 != len(names)):
+        raise click.BadParameter('length of names, paths does not match')
+
+    for i, name in enumerate(names):
+        if opts is None:
+            opts = {}
+
+        # Package the pretrained model artifact
+        svc.pack(name, paths[i])
+    
+    if files is not None:
+        filepaths = [x.strip() for x in files.split(',')]
+        for fp in filepaths:
+            with open(fp, 'r') as f:
+                content = f.read()
+
+            filename, ext = os.path.splitext(os.path.basename(fp))
+            svc.pack(filename, content)
+
     if labels is None:
         labels = {}
     else:
         labels = convert_labels(labels)
 
-    if opts is None:
-        opts = {}
-
-    # Create a service instance
-    svc = get_instance(module, clz)
-
-    # Package the pretrained model artifact
-    svc.pack(name, path)
-
     # Save the service to the model registry for serving
     saved_path = svc.save(labels=labels)
 
@@ -64,7 +80,8 @@ def convert_labels(labels_str):
 @click.option('--bucket', help='bucket name of pretrained model', default='models')
 @click.option('--path', help='directory path of pretrained model')
 @click.option('--labels', help='comma separated list of key:val pairs')
-def pack_from_s3(module, clz, name, bucket, path, labels=None, opts=None):
+@click.option('--files', help='comma separated list of file paths to add')
+def pack_from_s3(module, clz, name, bucket, path, labels=None, files=None, opts=None):
     s3 = boto3.resource('s3',
         endpoint_url=os.environ['S3_ENDPOINT_URL'],
         aws_access_key_id=os.environ['AWS_ACCESS_KEY_ID'],
@@ -89,29 +106,44 @@ def pack_from_s3(module, clz, name, bucket, path, labels=None, opts=None):
                 continue
             bucket.download_file(obj.key, target)
 
-    tmp_path = '/tmp/{}/{}'.format(bucket, path)
+    names = [x.strip() for x in name.split(',')]
+    buckets = [x.strip() for x in bucket.split(',')]
+    paths = [x.strip() for x in path.split(',')]
+    if ((len(names) + len(buckets) + len(paths)) / 3 != len(names)):
+        raise click.BadParameter('length of names, buckets, paths does not match')
 
-    if not os.path.exists(tmp_path):
-        download_directory(bucket, path)
+    # Create a service instance
+    svc = get_instance(module, clz)
+
+    for i, name in enumerate(names):
+        tmp_path = '/tmp/{}/{}'.format(buckets[i], paths[i])
+
+        if not os.path.exists(tmp_path):
+            download_directory(buckets[i], paths[i])
+
+        if opts is None:
+            opts = {}
+
+        # Package the pretrained model artifact
+        svc.pack(name, tmp_path)
+
+    if files is not None:
+        filepaths = [x.strip() for x in files.split(',')]
+        for fp in filepaths:
+            with open(fp, 'r') as f:
+                content = f.read()
+
+            filename, ext = os.path.splitext(os.path.basename(fp))
+            svc.pack(filename, content)
 
     if labels is None:
         labels = {}
     else:
         labels = convert_labels(labels)
 
-    if opts is None:
-        opts = {}
-
-    # Create a service instance
-    svc = get_instance(module, clz)
-
-    # Package the pretrained model artifact
-    svc.pack(name, tmp_path)
-
     # Save the service to the model registry for serving
     saved_path = svc.save(labels=labels)
 
-    #print('Saved model to ' + saved_path)
     click.echo(saved_path)
 
 
